@@ -1,13 +1,7 @@
 # -*- coding: utf-8 -*-
 """Python lager brewed by a loguru"""
 from lager import logging
-from lager._version import (
-    VERSION_INFO,
-    VERSION_MAJOR,
-    VERSION_MINOR,
-    VERSION_PATCH,
-    __version__,
-)
+from lager._meta import __version__
 from lager.const import LAGER_PORT, LOGURU_DEFAULT_FMT, TORNADO_FMT
 from lager.core import LN, LOG, flog, handlers, ln, log, logger, loglevel
 
@@ -22,7 +16,10 @@ __all__ = [
     'LOGURU_DEFAULT_FMT',
     'TORNADO_FMT',
     'loglevel',
+    'handlers',
+    'flog',
     'logger',
+    'logging',
     'LOG',
     'log',
     'LN',
